/*******************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File Name : Body_Part_Viewer.pov
 Version   : POV v 3.1 : Blob_Man v3.6
 Desciption: View the inividual body parts of Blob Man
             Use it to check positioning of Limb Objects
 Date      : 01 March 2000
 Author    : Peter Houston
 Email     : houston.graphics@iname.com
 WWW       : http://welcome.to/HoustonGraphics
             http://members.xoom.com/HoustonGraph
********************************************************/
#include "blob_man.inc"

/*******************************************************
Include the Costume Definition File Here
********************************************************/
//#include "sample.cdf"
#ifndef (CDF)
    #declare CDF=false;
#end
/*******************************************************
    Body Part Switch Number
    =======================
    1  = Head
    2  = Torso
    3  = Upperarm Right
    4  = Upperarm Left
    5  = Forearm Right
    6  = Forearm Left
    7  = Hand Right
    8  = Hand Left
    9  = Thigh Right
    10 = Thigh Left
    11 = Calf Right
    12 = Calf Left 
    13 = Foot Right
    14 = Foot Left
********************************************************/
#declare Body_Part_Switch = 9;

#declare Fingers=0; // 0=Straight, 1=Relaxed ,2=Curled
#declare BM_Jaw=1; // Jaw - Range : 0=Closed 1=Open
#declare BM_Mouth=.5; // Mouth Width - Range -0.5 - 0.5

#if (CDF=false)  // The following options only apply if no CDF is included (see above)
    #declare BM_Jowls=0; // Jowl Mass Range: 0-3
    #declare BM_Teeth=1; // 0 = No Teeth, 1 = Teeth
    #declare BM_Nose=.5; // Nose Size Range : 0 - 1.25 : Default=0.5
    #declare BM_Brow=1; // Brow Ridge 0=Off 1=On
    #declare BM_BodyStyle=1; // 0= Original, 1=New
#end
#declare BM_R_Thigh_Mass =3;
#declare ShowXYZ=off;  // Places a visible marker at <0,0,0>

// Please Note that the DeBug variable does not work in this file.

#declare nul=sphere{0,.0000001 pigment {rgbft 1}}
#declare XYZ= union {cylinder {<-8,0,0><8,0,0>.25 pigment {rgb x}}
                     cylinder {<0,-8,0><0,8,0>.25 pigment {rgb y}}
                     cylinder {<0,0,-8><0,0,8>.25 pigment {rgb z}}
              }

#switch (Body_Part_Switch)
    #case (1)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*2 translate y*2}
        #declare Title="Head"
        #if (ShowXYZ=on)
            #declare Head_Object=union {object {Head_Object} object {XYZ}}
        #end
        #declare BodyPart = 
            union {
                head(0.5,<.75,1,1>,0,1,0,0,0,0,0,1)
                translate y*-5
                scale 2
            }
    #break
    #case (2)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5}
        #declare Title="Torso"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
    
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Torso_Object=union {object {Torso_Object} object {XYZ}}
        #end
   
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                scale 1.5
            }
    #break
    #case (3)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5}
        #declare Title="Right Upperarm"
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Upperarm_R_Object=union {object {Upperarm_R_Object} object {XYZ}}
        #end
    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <9,-5,0>
                scale 1.5
            }
    #break
    #case (4)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5}
        #declare Title="Left Upperarm"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Upperarm_L_Object=union {object {Upperarm_L_Object} object {XYZ}}
        #end
    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <-9,-5,0>
                scale 1.5
            }
    #break
    #case (5)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5}
        #declare Title="Right Forearm"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Forearm_R_Object=union {object {Forearm_R_Object} object {XYZ}}
        #end    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> )
                translate <9,6,0>
                scale 1.5
            }
    #break
    #case (6)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5}
        #declare Title="Left Forearm"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Forearm_L_Object=union {object {Forearm_L_Object} object {XYZ}}
        #end    
    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <-9,12,0>
                scale 1.5
            }
    #break
    #case (7)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*3.5 translate y*3.5}
        #declare Title="Right Hand"
        #if (ShowXYZ=on)
            #declare Hand_R_Object=union {object {Hand_R_Object} object {XYZ scale .5}}
        #end    

        #declare BodyPart=
            object {
                hand(0.5,<0,0,0>,<0,0,0>,<0,0,0>,-1,0,Fingers,Fingers,Fingers,Fingers,Fingers)
                translate <9,30,0>
                scale 3.5
            }
    #break
    #case (8)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*3.5 translate y*3.5}
        #declare Title="Left - Hand"
        #if (ShowXYZ=on)
            #declare Hand_L_Object=union {object {Hand_L_Object} object {XYZ scale .5}}
        #end    

        #declare BodyPart=
            union {
                hand(0.5,<0,0,0>,<0,0,0>,<0,0,0>,1,0,Fingers,Fingers,Fingers,Fingers,Fingers)
                translate <-9,30,0>
                scale 3.5
            }
    #break
    #case (9)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5 translate y*1.5}
        #declare Title="Right Thigh"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Thigh_R_Object=union {object {Thigh_R_Object} object {XYZ}}
        #end    

        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <4,18,0>
                scale 1.5
            }
    #break
    #case (10)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5 translate y*1.5}
        #declare Title="Left Thigh"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Thigh_L_Object=union {object {Thigh_L_Object} object {XYZ}}
        #end    
    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <-4,18,0>
                scale 1.5
            }
    #break
    #case (11)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5 translate y*1.5}
        #declare Title="Right Calf"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_L_Calf_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Calf_R_Object=union {object {Calf_R_Object} object {XYZ}}
        #end    
    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <4,32,0>
                scale 1.5
            }
    #break
    #case (12)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*1.5 translate y*1.5}
        #declare Title="Left Calf"
        #declare BM_R_Upperarm_Mass=0;
        #declare BM_R_Forearm_Mass=0;
        #declare BM_L_Upperarm_Mass=0;
        #declare BM_L_Forearm_Mass=0;
        #declare BM_R_Thigh_Mass=0;
        #declare BM_R_Calf_Mass=0;
        #declare BM_L_Thigh_Mass=0;
        #declare BM_Torso_Mass=0;
    
        #declare Torso_Object=object{nul}
        #declare Upperarm_R_Object=object{nul}
        #declare Upperarm_L_Object=object{nul}
        #declare Forearm_R_Object=object{nul}
        #declare Forearm_L_Object=object{nul}
        #declare Thigh_R_Object=object{nul}
        #declare Thigh_L_Object=object{nul}
        #declare Calf_R_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Calf_L_Object=union {object {Calf_L_Object} object {XYZ}}
        #end    

    
        #declare BodyPart=
            union {
                torso( 0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0> ) 
                translate <-4,32,0>
                scale 1.5
            }
    #break
    #case (13)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*2}
        #declare Title="Right Foot"
        #declare BM_L_Foot=0;
        #declare Foot_L_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Foot_R_Object=union {object {Foot_R_Object} object {XYZ scale .75}}
        #end    
    
        #declare BodyPart=
            union {
                feet(0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>)
                translate <4,50,0>
                scale 2
            }
    #break
    #case (14)
        plane {z,100  pigment {checker rgb .15,rgb .25} scale 2*2}
        #declare Title="Left Foot"
        #declare BM_R_Foot=0;
        #declare Foot_R_Object=object{nul}
        #if (ShowXYZ=on)
            #declare Foot_L_Object=union {object {Foot_L_Object} object {XYZ scale .75}}
        #end    

    
        #declare BodyPart=
            union {
                feet(0.5,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>,<0,0,0>)
                translate <-4,50,0>
                scale 2
            }
    #break
#end

/****************************************************************
 Lights, Camera and Setting
*****************************************************************/
camera{location <0,-40,-100> orthographic look_at <0,-40,0> }
light_source{<-200,200,-200> rgb <1,.9,.5> }
light_source{< 400,400,-200> rgb <.2,.4,.8> shadowless }
light_source{<-200,200,-200> rgb .7         shadowless }
light_source{< 100, 50,-150> rgb .5         shadowless }
light_source{< 100,-50,-150> rgb .3         shadowless }
light_source{<-100,-50,-150> rgb .1         shadowless }
background {rgb 0}

/****************************************************************
 The Models
****************************************************************/
text { 
    ttf           
    "crystal.ttf",
    concat (Title," - 1 Square = 2 Units"),
    .1,
    0
    translate <-9,1,-5>
    pigment {rgb 1}
    finish {ambient 1}
    scale 7.5
    no_shadow
}

object {BodyPart              translate x*-15 no_shadow}
object {BodyPart rotate y*180 translate x* 45 no_shadow}
object {BodyPart rotate y* 90 translate x*-45 no_shadow}
object {BodyPart rotate y*-90 translate x* 15 no_shadow}
object {BodyPart rotate x*-90 translate y*-75 translate x*-15 no_shadow}
object {BodyPart rotate y*180 rotate x*90     translate y*-75 translate x* 45 no_shadow}

// EOF